@@ -1,5 +1,4 @@
 /*
- * @licence app begin@
  * SPDX license identifier: MPL-2.0
  *
  * Copyright (C) 2011-2015, BMW AG
@@ -12,7 +11,6 @@
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * For further information see http://www.genivi.org/.
- * @licence end@
  */
 
 /*!
@@ -94,8 +92,11 @@ extern "C" {
 #   define DLT_USER_RESENDBUF_MAX_SIZE (DLT_USER_BUF_MAX_SIZE + 100)    /**< Size of resend buffer; Max DLT message size is 1390 bytes plus some extra header space  */
 
 /* Use a semaphore or mutex from your OS to prevent concurrent access to the DLT buffer. */
-#   define DLT_SEM_LOCK() { sem_wait(&dlt_mutex); }
-#   define DLT_SEM_FREE() { sem_post(&dlt_mutex); }
+#define DLT_SEM_LOCK() do{\
+    while ((sem_wait(&dlt_mutex) == -1) && (errno == EINTR)) \
+        continue;       /* Restart if interrupted */ \
+    } while(0)
+#define DLT_SEM_FREE() { sem_post(&dlt_mutex); }
 
 /**
  * This structure is used for every context used in an application.
@@ -237,7 +238,9 @@ typedef struct
     int corrupt_message_size;
     int16_t corrupt_message_size_size;
 #   endif
+#   ifdef DLT_USE_UNIX_SOCKET_IPC
     DltUserConnectionState connection_state;
+#   endif
     uint16_t log_buf_len;        /**< length of message buffer, by default: DLT_USER_BUF_MAX_SIZE */
 } DltUser;
 
@@ -511,11 +514,11 @@ DltReturnValue dlt_check_library_version(const char *user_major_version, const c
 
 /**
  * Register an application in the daemon.
- * @param appid four byte long character array with the application id
+ * @param apid four byte long character array with the application id
  * @param description long name of the application
  * @return Value from DltReturnValue enum
  */
-DltReturnValue dlt_register_app(const char *appid, const char *description);
+DltReturnValue dlt_register_app(const char *apid, const char *description);
 
 /**
  * Unregister an application in the daemon.
@@ -565,7 +568,7 @@ DltReturnValue dlt_register_context_ll_ts(DltContext *handle,
  * @param handle pointer to an object containing information about one special logging context
  * @param contextid four byte long character array with the context id
  * @param description long name of the context
- * @param callback fn This is the fn which will be called when log level is changed
+ * @param *dlt_log_level_changed_callback This is the fn which will be called when log level is changed
  * @return Value from DltReturnValue enum
  */
 DltReturnValue dlt_register_context_llccb(DltContext *handle,
@@ -626,6 +629,7 @@ DltReturnValue dlt_register_injection_callback(DltContext *handle, uint32_t serv
  * @param handle pointer to an object containing information about one special logging context
  * @param service_id the service id to be waited for
  * @param (*dlt_injection_callback) function pointer to callback function
+ * @param priv private data
  * @return Value from DltReturnValue enum
  */
 DltReturnValue dlt_register_injection_callback_with_id(DltContext *handle, uint32_t service_id,
@@ -654,8 +658,8 @@ DltReturnValue dlt_verbose_mode(void);
 
 /**
  * Check the version of dlt library with library version used of the application.
- * @param Major version number of application - see dlt_version.h
- * @param Minor version number of application - see dlt_version.h
+ * @param user_major_version version number of application - see dlt_version.h
+ * @param user_minor_version version number of application - see dlt_version.h
  *  @return Value from DltReturnValue enum, DLT_RETURN_ERROR if there is a mismatch
  */
 DltReturnValue dlt_user_check_library_version(const char *user_major_version, const char *user_minor_version);
@@ -721,6 +725,10 @@ DltReturnValue dlt_set_application_ll_ts_limit(DltLogLevelType loglevel, DltTrac
  * - no ctid, apid matches: use ll with prio 3
  * - apid, ctid matches: use ll with prio 4
  *
+ * @param ll_set
+ * @param apid
+ * @param ctid
+ * @param ll
  * If no item matches or in case of error, the original log-level (\param ll) is returned
  */
 int dlt_env_adjust_ll_from_env(dlt_env_ll_set const *const ll_set,
@@ -819,14 +827,6 @@ DltReturnValue dlt_log_raw(DltContext *handle, DltLogLevelType loglevel, void *d
  */
 DltReturnValue dlt_log_marker();
 
-/**
- * Forward a complete DLT message to the DLT daemon
- * @param msgdata Message data of DLT message
- * @param size Size of DLT message
- * @return Value from DltReturnValue enum
- */
-DltReturnValue dlt_forward_msg(void *msgdata, size_t size);
-
 /**
  * Get the total size and available size of the shared memory buffer between daemon and applications.
  * This information is useful to control the flow control between applications and daemon.
