@@ -1,5 +1,4 @@
 /*
- * @licence app begin@
  * SPDX license identifier: MPL-2.0
  *
  * Copyright (C) 2011-2015, BMW AG
@@ -12,7 +11,6 @@
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * For further information see http://www.genivi.org/.
- * @licence end@
  */
 
 /*!
@@ -79,6 +77,7 @@
 
 #   include <limits.h>
 #   include <semaphore.h>
+#   include <stdbool.h>
 #   include "dlt_common.h"
 #   include "dlt_user.h"
 #   include "dlt_offline_logstorage.h"
@@ -97,10 +96,23 @@ extern "C" {
 
 /* Use a semaphore or mutex from your OS to prevent concurrent access to the DLT buffer. */
 
-#   define DLT_DAEMON_SEM_LOCK() { sem_wait(&dlt_daemon_mutex); }
-#   define DLT_DAEMON_SEM_FREE() { sem_post(&dlt_daemon_mutex); }
+#define DLT_DAEMON_SEM_LOCK() do{\
+    while ((sem_wait(&dlt_daemon_mutex) == -1) && (errno == EINTR)) \
+        continue;       /* Restart if interrupted */ \
+    } while(0)
+
+#define DLT_DAEMON_SEM_FREE() { sem_post(&dlt_daemon_mutex); }
 extern sem_t dlt_daemon_mutex;
 
+/* UDPMulticart Default IP and Port */
+#   ifdef UDP_CONNECTION_SUPPORT
+    #      define MULTICASTIPADDRESS "225.0.0.37"
+    #      define MULTICASTIPPORT 3491
+    #      define MULTICASTIP_MAX_SIZE 256
+    #      define MULTICAST_CONNECTION_DISABLED 0
+    #      define MULTICAST_CONNECTION_ENABLED 1
+#   endif
+
 /**
  * Definitions of DLT daemon logging states
  */
@@ -138,6 +150,7 @@ typedef struct
     int user_handle;    /**< connection handle for connection to user application */
     char *context_description; /**< context description */
     int8_t storage_log_level; /**< log level set for offline logstorage */
+    bool predefined; /**< set to true if this context is predefined by runtime configuration file */
 } DltDaemonContext;
 
 /*
@@ -234,7 +247,7 @@ DltDaemonRegisteredUsers *dlt_daemon_find_users_list(DltDaemon *daemon,
 /**
  * Loads the user saved configurations to daemon
  * @param daemon pointer to dlt daemon structure
- * @param runtime directory path
+ * @param runtime_directory directory path
  * @param verbose if set to true verbose information is printed out
  * @return DLT_RETURN_OK on success, DLT_RETURN_ERROR otherwise
  */
@@ -482,7 +495,7 @@ void dlt_daemon_user_send_all_log_state(DltDaemon *daemon, int verbose);
  * @param filename1 name of file containing the runtime defaults for contexts
  * @param InitialContextLogLevel loglevel to be sent to context when those register with loglevel default, read from dlt.conf
  * @param InitialContextTraceStatus tracestatus to be sent to context when those register with tracestatus default, read from dlt.conf
- * @param ForceLLTS force default log-level
+ * @param InitialEnforceLlTsStatus force default log-level
  * @param verbose if set to true verbose information is printed out.
  */
 void dlt_daemon_control_reset_to_factory_default(DltDaemon *daemon,
