@@ -1,5 +1,4 @@
 /**
- * @licence app begin@
  * Copyright (C) 2013 - 2015  Advanced Driver Information Technology.
  * This code is developed by Advanced Driver Information Technology.
  * Copyright of Advanced Driver Information Technology, Bosch and DENSO.
@@ -17,7 +16,6 @@
  *
  * \file: dlt_offline_logstorage.c
  * For further information see http://www.genivi.org/.
- * @licence end@
  */
 #include <stdio.h>
 #include <string.h>
@@ -79,20 +77,31 @@ DLT_STATIC void dlt_logstorage_filter_config_free(DltLogStorageFilterConfig *dat
     }
 }
 
+/**
+ * dlt_logstorage_list_destroy
+ *
+ * Destroy Filter configurations list.
+ *
+ * @param list List of the filter configurations will be destroyed.
+ * @param uconfig User configurations for log file
+ * @param dev_path Path to the device
+ * @param reason Reason for the destroying of Filter configurations list
+ * @return 0 on success, -1 on error
+ */
 DLT_STATIC int dlt_logstorage_list_destroy(DltLogStorageFilterList **list,
+                                           DltLogStorageUserConfig *uconfig,
+                                           char *dev_path,
                                            int reason)
 {
     DltLogStorageFilterList *tmp = NULL;
-    DltLogStorageUserConfig *uconfig = NULL;
-    char *dev_path = NULL;
 
     while (*(list) != NULL) {
         tmp = *list;
         *list = (*list)->next;
-
-        if (tmp->key != NULL) {
-            free(tmp->key);
-            tmp->key = NULL;
+        if (tmp->key_list != NULL)
+        {
+            free(tmp->key_list);
+            tmp->key_list = NULL;
         }
 
         if (tmp->data != NULL) {
@@ -148,21 +157,25 @@ DLT_STATIC int dlt_logstorage_list_add_config(DltLogStorageFilterConfig *data,
     return 0;
 }
 
-DLT_STATIC int dlt_logstorage_list_add(char *key,
+/**
+ * dlt_logstorage_list_add
+ *
+ * Add Filter configurations to the list.
+ *
+ * @param keys Keys will be added to the list.
+ * @param num_keys Number of keys
+ * @param data Filter configurations data will be added to the list.
+ * @param list List of the filter configurations
+ * @return 0 on success, -1 on error
+ */
+DLT_STATIC int dlt_logstorage_list_add(char *keys,
+                                       int num_keys,
                                        DltLogStorageFilterConfig *data,
                                        DltLogStorageFilterList **list)
 {
     DltLogStorageFilterList *tmp = NULL;
 
     while (*(list) != NULL) {
-        /* if the key is already present then the data should be updated */
-        if (strncmp((*list)->key, key, DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN) == 0) {
-            if (dlt_logstorage_list_add_config(data, &((*list)->data)) != 0)
-                return -1;
-
-            return 0;
-        }
-
         list = &(*list)->next;
     }
 
@@ -171,24 +184,34 @@ DLT_STATIC int dlt_logstorage_list_add(char *key,
     if (tmp == NULL)
         return -1;
 
-    tmp->key = strdup(key);
+    tmp->key_list = (char *)calloc(
+                (num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN), sizeof(char));
+    if (tmp->key_list == NULL)
+    {
+        free(tmp);
+        tmp = NULL;
+        return -1;
+    }
+
+    memcpy(tmp->key_list, keys, num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN);
+    tmp->num_keys = num_keys;
     tmp->next = NULL;
     tmp->data = calloc(1, sizeof(DltLogStorageFilterConfig));
 
     if (tmp->data == NULL) {
-        free(tmp->key);
+        free(tmp->key_list);
+        tmp->key_list = NULL;
         free(tmp);
-        tmp->key = NULL;
         tmp = NULL;
         return -1;
     }
 
     if (dlt_logstorage_list_add_config(data, &(tmp->data)) != 0) {
-        free(tmp->key);
+        free(tmp->key_list);
+        tmp->key_list = NULL;
         free(tmp->data);
-        free(tmp);
-        tmp->key = NULL;
         tmp->data = NULL;
+        free(tmp);
         tmp = NULL;
         return -1;
     }
@@ -198,17 +221,39 @@ DLT_STATIC int dlt_logstorage_list_add(char *key,
     return 0;
 }
 
-DLT_STATIC void *dlt_logstorage_list_find(char *key,
-                                          DltLogStorageFilterList **list)
+/**
+ * dlt_logstorage_list_find
+ *
+ * Find all Filter configurations corresponding with key provided.
+ *
+ * @param key Key to find the filter configurations
+ * @param list List of the filter configurations
+ * @param config Filter configurations corresponding with the key.
+ * @return Number of the filter configuration found.
+ */
+DLT_STATIC int dlt_logstorage_list_find(char *key,
+                                        DltLogStorageFilterList **list,
+                                        DltLogStorageFilterConfig **config)
 {
+    int i = 0;
+    int num = 0;
+
     while (*(list) != NULL) {
-        if (strncmp((*list)->key, key, DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN) == 0)
-            return (*list)->data;
-        else
-            list = &(*list)->next;
+        for (i = 0; i < (*list)->num_keys; i++)
+        {
+            if (strncmp(((*list)->key_list
+                        + (i * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN)),
+                        key, DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN) == 0)
+            {
+                config[num] = (*list)->data;
+                num++;
+                break;
+            }
+        }
+        list = &(*list)->next;
     }
 
-    return NULL;
+    return num;
 }
 
 /* Configuration file parsing helper functions */
@@ -250,7 +295,8 @@ void dlt_logstorage_free(DltLogStorage *handle, int reason)
         return;
     }
 
-    dlt_logstorage_list_destroy(&(handle->config_list), reason);
+    dlt_logstorage_list_destroy(&(handle->config_list), &handle->uconfig,
+                                handle->device_mount_point, reason);
 }
 
 
@@ -311,7 +357,7 @@ DLT_STATIC int dlt_logstorage_read_list_of_names(char **names, char *value)
         strncpy((*names + y), tok, len);
 
         if ((num > 1) && (i < num))
-            strncpy((*names + y + len), ",", 1);
+            strncpy((*names + y + len), ",", 2);
 
         y += len + 1;
 
@@ -331,7 +377,7 @@ DLT_STATIC int dlt_logstorage_read_list_of_names(char **names, char *value)
  * Non-digit characters including spaces and out of boundary will lead to an
  * error -1.
  *
- * @param file_name    string to store the file name
+ * @param number       Number to be read
  * @param value        string given in config file
  * @return             0 on success, -1 on error
  */
@@ -349,7 +395,7 @@ DLT_STATIC int dlt_logstorage_read_number(unsigned int *number, char *value)
 
     /* check if string consists of digits only */
     for (i = 0; i < len; i++)
-        if (isdigit(value[i] == 0)) {
+        if (!isdigit(value[i])) {
             dlt_log(LOG_ERR, "Invalid, is not a number \n");
             return -1;
         }
@@ -430,7 +476,7 @@ DLT_STATIC int dlt_logstorage_get_keys_list(char *ids, char *sep, char **list,
  * dlt_logstorage_create_keys_only_ctid
  *
  * Prepares keys with context ID alone, will use ecuid if provided
- * (ecuid::ctid) or (::ctid)
+ * (ecuid\:\:ctid) or (\:\:ctid)
  *
  * @param ecuid          ECU ID
  * @param ctid           Context ID
@@ -563,15 +609,15 @@ DLT_STATIC void dlt_logstorage_create_keys_only_ecu(char *ecuid, char *key)
  * wildcard. This will be rejected.
  *
  * If lists given for application and/or context id, all possible combinations
- * are returned as keys in a form "[apid][ctid], e.g. "APP1:CTX1".
- * If wildcards are used, the non-wildcard value becomes the key, e.g. "APP1:"
- * or ":CTX2".
+ * are returned as keys in a form "[apid][ctid], e.g. "APP1\:CTX1".
+ * If wildcards are used, the non-wildcard value becomes the key, e.g. "APP1\:"
+ * or "\:CTX2".
  *
- * @param[in]: apids: string given from filter configuration
- * @param[in]: ctids: string given from filter configuration
- * @param[in]: ecuid: string given from filter configuration
- * @param[out]: keys: keys to fill into hash table
- * @param[out]: num_keys: number of keys
+ * @param[in] apids string given from filter configuration
+ * @param[in] ctids string given from filter configuration
+ * @param[in] ecuid string given from filter configuration
+ * @param[out] keys keys to fill into hash table
+ * @param[out] num_keys number of keys
  * @return: 0 on success, error on failure*
  */
 DLT_STATIC int dlt_logstorage_create_keys(char *apids,
@@ -611,7 +657,7 @@ DLT_STATIC int dlt_logstorage_create_keys(char *apids,
 
     /* obtain key list and number of keys for application ids */
     if (dlt_logstorage_get_keys_list(apids, ",", &apid_list, &num_apids) != 0) {
-        dlt_log(LOG_ERR, "Failed to obtain appid, check configuration file \n");
+        dlt_log(LOG_ERR, "Failed to obtain apid, check configuration file \n");
         return -1;
     }
 
@@ -667,7 +713,7 @@ DLT_STATIC int dlt_logstorage_create_keys(char *apids,
  * Prepares hash table with keys and data
  *
  * @param handle         DLT Logstorage handle
- * @param tmp_data       Holds all other configuration values
+ * @param data           Holds all other configuration values
  * @return               0 on success, -1 on error
  */
 DLT_STATIC int dlt_logstorage_prepare_table(DltLogStorage *handle,
@@ -676,7 +722,6 @@ DLT_STATIC int dlt_logstorage_prepare_table(DltLogStorage *handle,
     int ret = 0;
     int num_keys = 0;
     char *keys = NULL;
-    int idx = 0;
 
     if ((handle == NULL) || (data == NULL)) {
         dlt_vlog(LOG_ERR, "Invalid parameters in %s\n", __func__);
@@ -695,24 +740,20 @@ DLT_STATIC int dlt_logstorage_prepare_table(DltLogStorage *handle,
     }
 
     /* hash_add */
-    for (idx = 0; idx < num_keys; idx++) {
-        if (dlt_logstorage_list_add(keys + (idx * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN),
-                                    data,
-                                    &(handle->config_list)) != 0) {
-            dlt_log(LOG_ERR,
-                    "Adding to hash table failed, returning failure\n");
-
-            dlt_logstorage_free(handle, DLT_LOGSTORAGE_SYNC_ON_ERROR);
-
-            free(keys);
-            return -1;
-        }
-
-        /* update filter keys and number of keys */
-        handle->num_filter_keys += 1;
+    if (dlt_logstorage_list_add(keys,
+                                num_keys,
+                                data,
+                                &(handle->config_list)) != 0)
+    {
+        dlt_log(LOG_ERR, "Adding to hash table failed, returning failure\n");
+        dlt_logstorage_free(handle, DLT_LOGSTORAGE_SYNC_ON_ERROR);
+        free(keys);
+        keys = NULL;
+        return -1;
     }
 
     free(keys);
+    keys = NULL;
     return 0;
 }
 
@@ -1329,8 +1370,7 @@ DLT_STATIC int dlt_logstorage_setup_table(DltLogStorage *handle,
     ret = dlt_logstorage_prepare_table(handle, tmp_data);
 
     if (ret != 0) {
-        dlt_vlog(LOG_ERR, "%s Error: Storing filter values failed\n",
-                 __func__);
+        dlt_vlog(LOG_ERR, "%s Error: Storing filter values failed\n", __func__);
         ret = DLT_OFFLINE_LOGSTORAGE_STORE_FILTER_ERROR;
     }
 
@@ -1405,17 +1445,16 @@ DLT_STATIC int dlt_daemon_offline_setup_filter_properties(DltLogStorage *handle,
     ret = dlt_logstorage_setup_table(handle, &tmp_data);
 
     if (ret != 0) {
-        dlt_vlog(LOG_ERR, "%s Error: Storing filter values failed\n",
-                 __func__);
+        dlt_vlog(LOG_ERR, "%s Error: Storing filter values failed\n", __func__);
         ret = DLT_OFFLINE_LOGSTORAGE_STORE_FILTER_ERROR;
     }
     else { /* move to next free filter configuration, if no error occurred */
         handle->num_configs += 1;
-
-        /* free tmp_data */
-        dlt_logstorage_filter_config_free(&tmp_data);
     }
 
+    /* free tmp_data */
+    dlt_logstorage_filter_config_free(&tmp_data);
+
     return ret;
 }
 
@@ -1510,12 +1549,12 @@ DLT_STATIC int dlt_logstorage_store_filters(DltLogStorage *handle,
  *
  * Combination of two wildcards is not allowed.
  *
- * @param input_file    pointer to configuration file stored on device
+ * @param handle        DLT Logstorage handle
  * @return              0 on success, -1 on error, 1 on warning
  */
 DLT_STATIC int dlt_logstorage_load_config(DltLogStorage *handle)
 {
-    char config_file_name[PATH_MAX + 1] = { '\0' };
+    char config_file_name[PATH_MAX] = {0};
     int ret = 0;
 
     /* Check if handle is NULL or already initialized or already configured  */
@@ -1540,7 +1579,7 @@ DLT_STATIC int dlt_logstorage_load_config(DltLogStorage *handle)
                 "Creating configuration file path string failed\n");
         return -1;
     }
-
+    config_file_name[PATH_MAX - 1] = 0;
     ret = dlt_logstorage_store_filters(handle, config_file_name);
 
     if (ret == 1) {
@@ -1585,10 +1624,11 @@ int dlt_logstorage_device_connected(DltLogStorage *handle, char *mount_point)
     }
 
     strncpy(handle->device_mount_point, mount_point, DLT_MOUNT_PATH_MAX);
+    handle->device_mount_point[DLT_MOUNT_PATH_MAX] = 0;
     handle->connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
     handle->config_status = 0;
     handle->write_errors = 0;
-    handle->num_filter_keys = 0;
+    handle->num_configs = 0;
 
     /* Setup logstorage with config file settings */
     return dlt_logstorage_load_config(handle);
@@ -1614,11 +1654,10 @@ int dlt_logstorage_device_disconnected(DltLogStorage *handle, int reason)
         dlt_logstorage_free(handle, reason);
 
     /* Reset all device status */
-    memset(handle->device_mount_point, '\0', sizeof(char) * DLT_MOUNT_PATH_MAX);
+    memset(handle->device_mount_point, 0, sizeof(char) * (DLT_MOUNT_PATH_MAX + 1));
     handle->connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_DISCONNECTED;
     handle->config_status = 0;
     handle->write_errors = 0;
-    handle->num_filter_keys = 0;
     handle->num_configs = 0;
 
     return 0;
@@ -1637,7 +1676,10 @@ int dlt_logstorage_device_disconnected(DltLogStorage *handle, int reason)
  */
 int dlt_logstorage_get_loglevel_by_key(DltLogStorage *handle, char *key)
 {
-    DltLogStorageFilterConfig *config = NULL;
+    DltLogStorageFilterConfig *config[DLT_CONFIG_FILE_SECTIONS_MAX] = { 0 };
+    int num_configs = 0;
+    int i = 0;
+    int log_level = 0;
 
     /* Check if handle is NULL,already initialized or already configured  */
     if ((handle == NULL) ||
@@ -1646,30 +1688,52 @@ int dlt_logstorage_get_loglevel_by_key(DltLogStorage *handle, char *key)
         (handle->config_status != DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE))
         return -1;
 
-    config = (DltLogStorageFilterConfig *)
-        dlt_logstorage_list_find(key, &(handle->config_list));
+    num_configs = dlt_logstorage_list_find(key, &(handle->config_list), config);
 
-    if (config == NULL) {
+    if (num_configs == 0)
+    {
         dlt_vlog(LOG_WARNING, "Configuration for key [%s] not found!\n", key);
         return -1;
     }
+    else if (num_configs == 1)
+    {
+        if (config[0] != NULL)
+        {
+            log_level = config[0]->log_level;
+        }
+    }
+    else
+    {
+        /**
+         * Multiple configurations found, raise a warning to the user and go
+         * for the more verbose one.
+         */
+        dlt_vlog(LOG_WARNING, "Multiple configuration for key [%s] found,"
+                 " return the highest log level!\n", key);
 
-    return config->log_level;
+        for (i = 0; i < num_configs; i++)
+        {
+            if ((config[i] != NULL) && (config[i]->log_level > log_level))
+            {
+                log_level = config[i]->log_level;
+            }
+        }
+    }
+
+    return log_level;
 }
 
 /**
  * dlt_logstorage_get_config
  *
  * Obtain the configuration data of all filters for provided apid and ctid
- * For a given apid and ctid, there can be 3 possiblities of configuration
- * data available in the Hash map, this function will return the address
- * of configuration data for all these 3 combinations
  *
  * @param handle    DltLogStorage handle
- * @param config    Pointer to array of filter configurations
+ * @param config    [out] Pointer to array of filter configurations
  * @param apid      application id
  * @param ctid      context id
- * @return          number of found configurations
+ * @param ecuid     ecu id
+ * @return          number of configurations found
  */
 int dlt_logstorage_get_config(DltLogStorage *handle,
                               DltLogStorageFilterConfig **config,
@@ -1677,13 +1741,14 @@ int dlt_logstorage_get_config(DltLogStorage *handle,
                               char *ctid,
                               char *ecuid)
 {
-    DltLogStorageFilterConfig *ptr_config = NULL;
-    char key[DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_CONFIGS][DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN] =
+    DltLogStorageFilterConfig **cur_config_ptr = NULL;
+    char key[DLT_CONFIG_FILE_SECTIONS_MAX][DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN] =
     { { '\0' }, { '\0' }, { '\0' } };
     int i = 0;
     int apid_len = 0;
     int ctid_len = 0;
     int ecuid_len = 0;
+    int num_configs = 0;
     int num = 0;
 
     /* Check if handle is NULL,already initialized or already configured  */
@@ -1714,15 +1779,9 @@ int dlt_logstorage_get_config(DltLogStorage *handle,
         strncat(key[0], ":", 1);
         strncat(key[0], ":", 1);
 
-        ptr_config = (DltLogStorageFilterConfig *)dlt_logstorage_list_find(
-            key[0], &(handle->config_list));
-
-        if (ptr_config != NULL) {
-            config[num] = ptr_config;
-            num += 1;
-        }
-
-        return num;
+        num_configs = dlt_logstorage_list_find(key[0], &(handle->config_list),
+                                               config);
+        return num_configs;
     }
 
     apid_len = strlen(apid);
@@ -1776,17 +1835,20 @@ int dlt_logstorage_get_config(DltLogStorage *handle,
     strncat(key[6], ":", 1);
 
     /* Search the list three times with keys as -apid: , :ctid and apid:ctid */
-    for (i = 0; i < DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_CONFIGS; i++) {
-        ptr_config = (DltLogStorageFilterConfig *)
-            dlt_logstorage_list_find(key[i], &(handle->config_list));
-
-        if (ptr_config != NULL) {
-            config[num] = ptr_config;
-            num += 1;
+    for (i = 0; i < DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_KEYS; i++)
+    {
+        cur_config_ptr = &config[num_configs];
+        num = dlt_logstorage_list_find(key[i], &(handle->config_list),
+                                       cur_config_ptr);
+        num_configs += num;
+        /* If all filter configurations matched, stop and return */
+        if (num_configs == handle->num_configs)
+        {
+            break;
         }
     }
 
-    return num;
+    return num_configs;
 }
 
 /**
@@ -1827,7 +1889,8 @@ DLT_STATIC int dlt_logstorage_filter(DltLogStorage *handle,
         return 0;
     }
 
-    for (i = 0; i < DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_CONFIGS; i++) {
+    for (i = 0 ; i < num ; i++)
+    {
         if (config[i] == NULL)
             continue;
 
@@ -1854,11 +1917,13 @@ DLT_STATIC int dlt_logstorage_filter(DltLogStorage *handle,
  * configuration.
  *
  * @param handle    DltLogStorage handle
- * @param config    User configurations for log file
+ * @param uconfig    User configurations for log file
  * @param data1     Data buffer of message header
  * @param size1     Size of message header buffer
- * @param data2     Data buffer of message body
- * @param size2     Size of message body
+ * @param data2     Data buffer of extended message body
+ * @param size2     Size of extended message body
+ * @param data3     Data buffer of message body
+ * @param size3     Size of message body
  * @return          0 on success or write errors < max write errors, -1 on error
  */
 int dlt_logstorage_write(DltLogStorage *handle,
@@ -1870,7 +1935,8 @@ int dlt_logstorage_write(DltLogStorage *handle,
                          unsigned char *data3,
                          int size3)
 {
-    DltLogStorageFilterConfig *config[DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_CONFIGS] = { 0 };
+    DltLogStorageFilterConfig *config[DLT_CONFIG_FILE_SECTIONS_MAX] = { 0 };
+
     int i = 0;
     int ret = 0;
     int num = 0;
@@ -1953,7 +2019,8 @@ int dlt_logstorage_write(DltLogStorage *handle,
     }
 
     /* store log message in every found filter */
-    for (i = 0; i < DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_CONFIGS; i++) {
+    for (i = 0; i < num; i++)
+    {
         if (config[i] == NULL)
             continue;
 
@@ -1970,6 +2037,8 @@ int dlt_logstorage_write(DltLogStorage *handle,
 
         if (ret == 0) { /* log data (write) */
             ret = config[i]->dlt_logstorage_write(config[i],
+                                                  uconfig,
+                                                  handle->device_mount_point,
                                                   data1,
                                                   size1,
                                                   data2,
