@@ -1,5 +1,4 @@
 /*
- * @licence app begin@
  * SPDX license identifier: MPL-2.0
  *
  * Copyright (C) 2011-2015, BMW AG
@@ -12,7 +11,6 @@
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * For further information see http://www.genivi.org/.
- * @licence end@
  */
 
 /*!
@@ -27,7 +25,7 @@
 
 /*******************************************************************************
 **                                                                            **
-**  SRC-MODULE: dlt-test-client.c                                             **
+**  SRC-MODULE: dlt-test-filetransfer.c                                       **
 **                                                                            **
 **  TARGET    : linux                                                         **
 **                                                                            **
@@ -375,9 +373,25 @@ int testFile3Run3()
     return 0;
 }
 
-/*!Main program dlt-test-filestransfer starts here */
-int main(void)
+void usage()
 {
+    char version[255];
+
+    dlt_get_version(version, 255);
+
+    printf("Usage: dlt-test-filestransfer [options]\n");
+    printf("Test filestransfer application by transfering files.\n");
+    printf("%s \n", version);
+    printf("Options:\n");
+    printf("    -h          display help information\n");
+    printf("    -t <path>   absolute path to a text file\n");
+    printf("    -i <path>   absolute path to an image file\n");
+}
+
+/*!Main program dlt-test-filestransfer starts here */
+int main(int argc, char* argv[])
+{
+    int c;
     /*First file contains some text */
     file1 = "/usr/local/share/dlt-filetransfer/dlt-test-filetransfer-file";
     /*Second file is a picture */
@@ -389,6 +403,33 @@ int main(void)
     /*Third file doesn't exist. Just to test the reaction when the file isn't available. */
     file3_3 = "dlt-test-filetransfer-doesntExist_3";
 
+    while((c = getopt(argc, argv, "ht:i:")) != -1)
+    {
+        switch (c)
+        {
+            case 't':
+            {
+                file1 = optarg;
+                break;
+            }
+            case 'i':
+            {
+                file2 = optarg;
+                break;
+            }
+            case 'h':
+            {
+                usage();
+                return 0;
+            }
+            default:
+            {
+                usage();
+                return -1;
+            }
+        }
+    }
+
     /*Register the application at the dlt-daemon */
     DLT_REGISTER_APP("FLTR", "Test Application filetransfer");
 
