@@ -37,15 +37,18 @@ TEST(t_dlt_logstorage_list_add, normal)
 {
     DltLogStorageFilterList *list = NULL;
     DltLogStorageFilterConfig *data = NULL;
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
     char key = 1;
+    int num_keys = 1;
 
     data = (DltLogStorageFilterConfig *)calloc(1, sizeof(DltLogStorageFilterConfig));
 
     if (data != NULL) {
         dlt_logstorage_filter_set_strategy(data, DLT_LOGSTORAGE_SYNC_ON_MSG);
 
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(&key, data, &list));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&list, 0));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(&key, num_keys, data, &list));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&list, &file_config, path, 0));
     }
 }
 
@@ -70,15 +73,18 @@ TEST(t_dlt_logstorage_list_destroy, normal)
 {
     DltLogStorageFilterList *list = NULL;
     DltLogStorageFilterConfig *data = NULL;
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
     char key = 1;
+    int num_keys = 1;
 
     data = (DltLogStorageFilterConfig *)calloc(1, sizeof(DltLogStorageFilterConfig));
 
     if (data != NULL) {
         dlt_logstorage_filter_set_strategy(data, DLT_LOGSTORAGE_SYNC_ON_MSG);
 
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(&key, data, &list));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&list, 0));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(&key, num_keys, data, &list));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&list, &file_config, path, 0));
     }
 }
 
@@ -87,10 +93,14 @@ TEST(t_dlt_logstorage_list_find, normal)
 {
     DltLogStorageFilterList *list = NULL;
     DltLogStorageFilterConfig *data = NULL;
-    DltLogStorageFilterConfig *retData;
-    char key[] = "1";
+    int num_configs = 0;
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
+    char key[] = ":1234:5678";
     char apid[] = "1234";
     char ctid[] = "5678";
+    int num_keys = 1;
+    DltLogStorageFilterConfig *config[DLT_CONFIG_FILE_SECTIONS_MAX] = { 0 };
 
     data = (DltLogStorageFilterConfig *)calloc(1, sizeof(DltLogStorageFilterConfig));
 
@@ -99,17 +109,17 @@ TEST(t_dlt_logstorage_list_find, normal)
         data->ctids = strdup(ctid);
         dlt_logstorage_filter_set_strategy(data, DLT_LOGSTORAGE_SYNC_ON_MSG);
 
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, data, &list));
+        ASSERT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, num_keys, data, &list));
 
-        retData = (DltLogStorageFilterConfig *)dlt_logstorage_list_find(key, &list);
-        EXPECT_NE((DltLogStorageFilterConfig *)NULL, retData);
+        num_configs = dlt_logstorage_list_find(key, &list, config);
 
-        if (retData != NULL) {
-            EXPECT_STREQ(apid, retData->apids);
-            EXPECT_STREQ(ctid, retData->ctids);
-        }
+        ASSERT_EQ(1, num_configs);
+        ASSERT_NE((DltLogStorageFilterConfig *)NULL, config[0]);
 
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&list, 0));
+        EXPECT_STREQ(apid, config[0]->apids);
+        EXPECT_STREQ(ctid, config[0]->ctids);
+
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&list, &file_config, path, 0));
     }
 }
 
@@ -122,13 +132,14 @@ TEST(t_dlt_logstorage_free, normal)
     int reason = 0;
     handle.num_configs = 0;
     handle.config_list = NULL;
+    int num_keys = 1;
 
     data = (DltLogStorageFilterConfig *)calloc(1, sizeof(DltLogStorageFilterConfig));
 
     if (data != NULL) {
         dlt_logstorage_filter_set_strategy(data, DLT_LOGSTORAGE_SYNC_ON_MSG);
 
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(&key, data, &handle.config_list));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(&key, num_keys, data, &handle.config_list));
 
         dlt_logstorage_free(&handle, reason);
     }
@@ -184,13 +195,14 @@ TEST(t_dlt_logstorage_prepare_table, normal)
 {
     DltLogStorage handle;
     DltLogStorageFilterConfig data;
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
     memset(&handle, 0, sizeof(DltLogStorage));
     memset(&data, 0, sizeof(DltLogStorageFilterConfig));
     char apids[] = "1234";
     char ctids[] = "5678";
     data.apids = apids;
     data.ctids = ctids;
-    handle.num_filter_keys = 1;
     data.records = NULL;
     data.log = NULL;
     data.cache = NULL;
@@ -198,7 +210,7 @@ TEST(t_dlt_logstorage_prepare_table, normal)
     dlt_logstorage_filter_set_strategy(&data, DLT_LOGSTORAGE_SYNC_ON_MSG);
 
     EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_prepare_table(&handle, &data));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&handle.config_list, 0));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&handle.config_list, &file_config, path, 0));
 }
 
 TEST(t_dlt_logstorage_prepare_table, null)
@@ -434,16 +446,17 @@ TEST(t_dlt_logstorage_check_param, null)
 TEST(t_dlt_logstorage_store_filters, normal)
 {
     DltLogStorage handle;
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
     char config_file_name[] = "/tmp/dlt_logstorage.conf";
     handle.connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
     handle.config_status = 0;
     handle.write_errors = 0;
-    handle.num_filter_keys = 0;
 
     handle.config_list = NULL;
 
     EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_store_filters(&handle, config_file_name));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&handle.config_list, 0));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&handle.config_list, &file_config, path, 0));
 }
 
 TEST(t_dlt_logstorage_store_filters, null)
@@ -455,15 +468,16 @@ TEST(t_dlt_logstorage_store_filters, null)
 TEST(t_dlt_logstorage_load_config, normal)
 {
     DltLogStorage handle;
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
     handle.connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
     handle.config_status = 0;
     handle.write_errors = 0;
-    handle.num_filter_keys = 0;
     handle.config_list = NULL;
     strncpy(handle.device_mount_point, "/tmp", DLT_MOUNT_PATH_MAX);
 
     EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_load_config(&handle));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&handle.config_list, 0));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_destroy(&handle.config_list, &file_config, path, 0));
 }
 
 TEST(t_dlt_logstorage_load_config, null)
@@ -478,7 +492,6 @@ TEST(t_dlt_logstorage_device_connected, normal)
     handle.connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_DISCONNECTED;
     handle.config_status = 0;
     handle.write_errors = 0;
-    handle.num_filter_keys = 0;
     handle.config_list = NULL;
     strncpy(handle.device_mount_point, "/tmp", DLT_MOUNT_PATH_MAX);
 
@@ -515,13 +528,14 @@ TEST(t_dlt_logstorage_get_loglevel_by_key, normal)
     handle.connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
     handle.config_status = DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE;
     handle.config_list = NULL;
+    int num_keys = 1;
 
     config = (DltLogStorageFilterConfig *)calloc(1, sizeof(DltLogStorageFilterConfig));
 
     if (config != NULL) {
         config->log_level = DLT_LOG_ERROR;
 
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, config, &(handle.config_list)));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, num_keys, config, &(handle.config_list)));
         EXPECT_GE(DLT_LOG_ERROR, dlt_logstorage_get_loglevel_by_key(&handle, key));
 
         free(config);
@@ -555,10 +569,11 @@ TEST(t_dlt_logstorage_get_config, normal)
     handle.connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
     handle.config_status = DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE;
     handle.config_list = NULL;
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, &value, &(handle.config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, &value, &(handle.config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, num_keys, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, num_keys, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, num_keys, &value, &(handle.config_list)));
 
     num_config = dlt_logstorage_get_config(&handle, config, apid, ctid, ecuid);
 
@@ -590,15 +605,16 @@ TEST(t_dlt_logstorage_filter, normal)
     char key0[] = ":1234:\000\000\000\000";
     char key1[] = "::5678\000\000\000\000";
     char key2[] = ":1234:5678";
-    DltLogStorageFilterConfig *config[DLT_OFFLINE_LOGSTORAGE_MAX_POSSIBLE_CONFIGS] = { 0 };
+    DltLogStorageFilterConfig *config[DLT_CONFIG_FILE_SECTIONS_MAX] = { 0 };
     DltLogStorage handle;
     handle.connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
     handle.config_status = DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE;
     handle.config_list = NULL;
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, &value, &(handle.config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, &value, &(handle.config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, num_keys, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, num_keys, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, num_keys, &value, &(handle.config_list)));
 
     num = dlt_logstorage_filter(&handle, config, apid, ctid, ecuid, 0);
 
@@ -638,10 +654,11 @@ TEST(t_dlt_logstorage_write, normal)
     char key0[] = ":1234:\000\000\000\000";
     char key1[] = "::5678\000\000\000\000";
     char key2[] = ":1234:5678";
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, &value, &(handle.config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, &value, &(handle.config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, num_keys, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, num_keys, &value, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, num_keys, &value, &(handle.config_list)));
     EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write(&handle, &uconfig, data1, size1, data2, size2, data3, size3));
 }
 
@@ -666,9 +683,11 @@ TEST(t_dlt_logstorage_sync_caches, normal)
     configs.ctids = ctid;
     configs.ecuid = ecuid;
     configs.file_name = filename;
+    int num_keys = 1;
+
     dlt_logstorage_filter_set_strategy(&configs, DLT_LOGSTORAGE_SYNC_ON_MSG);
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, &configs, &(handle.config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, num_keys, &configs, &(handle.config_list)));
     EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_sync_caches(&handle));
 }
 
@@ -913,12 +932,13 @@ TEST(t_dlt_logstorage_write_on_msg, normal)
     unsigned char data3[] = "dlt_data";
 
     EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_prepare_on_msg(&config, &file_config, path, 1));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_on_msg(&config, data1, size, data2, size, data3, size));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_on_msg(&config, &file_config, path,
+              data1, size, data2, size, data3, size));
 }
 
 TEST(t_dlt_logstorage_write_on_msg, null)
 {
-    EXPECT_EQ(DLT_RETURN_ERROR, dlt_logstorage_write_on_msg(NULL, NULL, 0, NULL, 0, NULL, 0));
+    EXPECT_EQ(DLT_RETURN_ERROR, dlt_logstorage_write_on_msg(NULL, NULL, NULL, NULL, 0, NULL, 0, NULL, 0));
 }
 
 /* Begin Method: dlt_logstorage::t_dlt_logstorage_sync_on_msg*/
@@ -985,12 +1005,15 @@ TEST(t_dlt_logstorage_write_msg_cache, normal)
     unsigned char data3[10] = "dlt_dat3";
     DltLogStorageFilterConfig config;
     memset(&config, 0, sizeof(DltLogStorageFilterConfig));
+    DltLogStorageUserConfig file_config;
+    char *path = (char*)"/tmp";
 
     config.cache = calloc(1, 50 + sizeof(DltLogStorageCacheFooter));
 
     if (config.cache != NULL) {
         config.file_size = 50;
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, data1, size, data2, size, data3, size));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, &file_config, path,
+                  data1, size, data2, size, data3, size));
 
         free(config.cache);
         config.cache = NULL;
@@ -999,31 +1022,31 @@ TEST(t_dlt_logstorage_write_msg_cache, normal)
 
 TEST(t_dlt_logstorage_write_msg_cache, null)
 {
-    EXPECT_EQ(DLT_RETURN_ERROR, dlt_logstorage_write_msg_cache(NULL, NULL, 0, NULL, 0, NULL, 0));
+    EXPECT_EQ(DLT_RETURN_ERROR, dlt_logstorage_write_msg_cache(NULL, NULL, NULL, NULL, 0, NULL, 0, NULL, 0));
 }
 
 /* Begin Method: dlt_logstorage::t_dlt_logstorage_split_key*/
 TEST(t_dlt_logstorage_split_key, normal)
 {
     char key[] = "dlt:1020:";
-    char appid[] = ":2345:";
-    char ctxid[] = "::6789";
+    char apid[] = ":2345:";
+    char ctid[] = "::6789";
     char ecuid[] = "ECU1";
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_split_key(key, appid, ctxid, ecuid));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_split_key(key, apid, ctid, ecuid));
 }
 
 TEST(t_dlt_logstorage_split_key, null)
 {
     char key[] = "dlt:1020:";
-    char appid[] = "2345";
-    char ctxid[] = "6789";
+    char apid[] = "2345";
+    char ctid[] = "6789";
     char ecuid[] = "ECU1";
     EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(NULL, NULL, NULL, NULL));
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(NULL, appid, ctxid, ecuid));
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(key, NULL, ctxid, ecuid));
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(key, appid, NULL, ecuid));
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(key, appid, ctxid, NULL));
+    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(NULL, apid, ctid, ecuid));
+    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(key, NULL, ctid, ecuid));
+    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(key, apid, NULL, ecuid));
+    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_split_key(key, apid, ctid, NULL));
 }
 
 /* Begin Method: dlt_logstorage::t_dlt_logstorage_update_all_contexts*/
@@ -1215,11 +1238,12 @@ TEST(t_dlt_daemon_logstorage_get_loglevel, normal)
 
     daemon.storage_handle = &storage_handle;
     daemon.storage_handle->connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
-    daemon.storage_handle->num_filter_keys = 1;
     daemon.storage_handle->config_status = DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE;
     daemon.storage_handle->config_list = NULL;
+    daemon.storage_handle->num_configs = 1;
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, &value, &(daemon.storage_handle->config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, num_keys, &value, &(daemon.storage_handle->config_list)));
     EXPECT_NO_THROW(dlt_daemon_logstorage_update_application_loglevel(&daemon, &daemon_local, device_index, 0));
 
     EXPECT_EQ(4, dlt_daemon_logstorage_get_loglevel(&daemon, 1, apid, ctid));
@@ -1267,11 +1291,11 @@ TEST(t_dlt_daemon_logstorage_update_application_loglevel, normal)
 
     daemon.storage_handle = &storage_handle;
     daemon.storage_handle->connection_type = DLT_OFFLINE_LOGSTORAGE_DEVICE_CONNECTED;
-    daemon.storage_handle->num_filter_keys = 1;
     daemon.storage_handle->config_status = DLT_OFFLINE_LOGSTORAGE_CONFIG_DONE;
     daemon.storage_handle->config_list = NULL;
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, &value, &(daemon.storage_handle->config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, num_keys, &value, &(daemon.storage_handle->config_list)));
     EXPECT_NO_THROW(dlt_daemon_logstorage_update_application_loglevel(&daemon, &daemon_local, device_index, 0));
 }
 
@@ -1324,10 +1348,11 @@ TEST(t_dlt_daemon_logstorage_write, normal)
     char key0[] = "1234:\000\000\000\000";
     char key1[] = ":5678\000\000\000\000";
     char key2[] = "1234:5678";
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, &value, &(daemon.storage_handle->config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, &value, &(daemon.storage_handle->config_list)));
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, &value, &(daemon.storage_handle->config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key0, num_keys, &value, &(daemon.storage_handle->config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key1, num_keys, &value, &(daemon.storage_handle->config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key2, num_keys, &value, &(daemon.storage_handle->config_list)));
     EXPECT_NO_THROW(dlt_daemon_logstorage_write(&daemon, &uconfig, data1, size, data2, size, data3, size));
 }
 
@@ -1420,8 +1445,9 @@ TEST(t_dlt_daemon_logstorage_sync_cache, normal)
     configs.ecuid = ecuid;
     configs.file_name = file_name;
     dlt_logstorage_filter_set_strategy(&configs, DLT_LOGSTORAGE_SYNC_ON_MSG);
+    int num_keys = 1;
 
-    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, &configs, &(daemon.storage_handle->config_list)));
+    EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_list_add(key, num_keys, &configs, &(daemon.storage_handle->config_list)));
     EXPECT_EQ(DLT_RETURN_OK, dlt_daemon_logstorage_sync_cache(&daemon, &daemon_local, path, 0));
 }
 
@@ -1481,55 +1507,35 @@ TEST(t_dlt_logstorage_find_dlt_header, null)
     }
 }
 
-/* Begin Method: dlt_logstorage::t_dlt_logstorage_sync_create_new_file*/
-TEST(t_dlt_logstorage_sync_create_new_file, normal)
+/* Begin Method: dlt_logstorage::t_dlt_logstorage_find_last_dlt_header*/
+TEST(t_dlt_logstorage_find_last_dlt_header, normal)
 {
-    DltLogStorageUserConfig file_config;
-    memset(&file_config, 0, sizeof(DltLogStorageUserConfig));
-    file_config.logfile_timestamp = 191132;
-    file_config.logfile_delimiter = { '_' };
-    file_config.logfile_maxcounter = 5;
-    file_config.logfile_counteridxlen = 2;
-    char *path = (char *)"/tmp";
+    char data[] = {'a','b','D','L','T',0x01};
     DltLogStorageFilterConfig config;
     memset(&config, 0, sizeof(DltLogStorageFilterConfig));
-    char apids;
-    char ctids;
-    config.apids = &apids;
-    config.ctids = &ctids;
-    config.file_name = (char *)"Test";
-    config.records = NULL;
-    config.log = NULL;
-    config.cache = NULL;
-    config.file_size = 50;
-    config.sync = DLT_LOGSTORAGE_SYNC_ON_DEMAND;
-    config.num_files = 5;
-    g_logstorage_cache_max = 16;
-    unsigned int size = 10;
-    unsigned char data1[10] = "dlt_data1";
-    unsigned char data2[10] = "dlt_data2";
-    unsigned char data3[10] = "dlt_data3";
-    DltLogStorageCacheFooter *footer = NULL;
-
-    config.cache = calloc(1, 50 + sizeof(DltLogStorageCacheFooter));
+    config.cache = calloc(1, sizeof(data));
 
     if (config.cache != NULL) {
-        footer = (DltLogStorageCacheFooter *)((unsigned char *)config.cache + 50);
+        strncpy((char *)config.cache, data, sizeof(data));
 
-        if (footer != NULL) {
-            EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_prepare_msg_cache(&config, &file_config, path, 1));
-            EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, data1, size, data2, size, data3, size));
-            footer->offset = 0;
-            EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_sync_create_new_file(&config, &file_config, path, 0));
-            free(config.cache);
-            config.cache = NULL;
-        }
+        /* DLT header starts from index 2 */
+        EXPECT_EQ(2, dlt_logstorage_find_last_dlt_header(config.cache, 0, sizeof(data)));
+        free(config.cache);
     }
 }
-
-TEST(t_dlt_logstorage_sync_create_new_file, null)
+TEST(t_dlt_logstorage_find_last_dlt_header, null)
 {
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_sync_create_new_file(NULL, NULL, NULL, 0));
+    char data[] = {'N','o','H','e','a','d','e','r'};
+    DltLogStorageFilterConfig config;
+    memset(&config, 0, sizeof(DltLogStorageFilterConfig));
+    config.cache = calloc(1, sizeof(data));
+    if (config.cache != NULL)
+    {
+        /* config.cache =(void *) "a,b,D,L,T,0x01"; */
+        strncpy((char *)config.cache, data, sizeof(data));
+        EXPECT_EQ(-1, dlt_logstorage_find_last_dlt_header(config.cache, 0, sizeof(data)));
+        free(config.cache);
+    }
 }
 
 /* Begin Method: dlt_logstorage::t_dlt_logstorage_sync_to_file*/
@@ -1552,7 +1558,6 @@ TEST(t_dlt_logstorage_sync_to_file, normal)
     config.records = NULL;
     config.log = NULL;
     config.cache = NULL;
-    config.file_size = 0;
     config.sync = DLT_LOGSTORAGE_SYNC_ON_DEMAND;
     config.num_files = 6;
     config.file_size = 50;
@@ -1561,13 +1566,19 @@ TEST(t_dlt_logstorage_sync_to_file, normal)
     unsigned char data1[10] = "dlt_data0";
     unsigned char data2[10] = "dlt_data1";
     unsigned char data3[10] = "dlt_data2";
+    DltLogStorageCacheFooter *footer = NULL;
 
-    config.cache = calloc(1, 50 + sizeof(DltLogStorageCacheFooter));
+    config.cache = calloc(1, config.file_size + sizeof(DltLogStorageCacheFooter));
 
     if (config.cache != NULL) {
         EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_prepare_msg_cache(&config, &file_config, path, 1));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, data1, size, data2, size, data3, size));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_sync_to_file(&config, &file_config, path));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, &file_config, path,
+                  data1, size, data2, size, data3, size));
+
+        footer = (DltLogStorageCacheFooter *)((uint8_t*)config.cache + config.file_size);
+
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_sync_to_file(&config, &file_config, path,
+                  footer, footer->last_sync_offset, footer->offset));
         free(config.cache);
         config.cache = NULL;
     }
@@ -1575,53 +1586,8 @@ TEST(t_dlt_logstorage_sync_to_file, normal)
 
 TEST(t_dlt_logstorage_sync_to_file, null)
 {
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_sync_to_file(NULL, NULL, NULL));
-}
+    EXPECT_EQ(-1, dlt_logstorage_sync_to_file(NULL, NULL, NULL, NULL, 0, 1));
 
-/* Begin Method: dlt_logstorage::t_dlt_logstorage_sync_capable_data_to_file*/
-TEST(t_dlt_logstorage_sync_capable_data_to_file, normal)
-{
-    DltLogStorageUserConfig file_config;
-    memset(&file_config, 0, sizeof(DltLogStorageUserConfig));
-    file_config.logfile_timestamp = 191132;
-    file_config.logfile_delimiter = { '_' };
-    file_config.logfile_maxcounter = 7;
-    file_config.logfile_counteridxlen = 2;
-    char *path = (char *)"/tmp";
-    DltLogStorageFilterConfig config;
-    memset(&config, 0, sizeof(DltLogStorageFilterConfig));
-    char apids;
-    char ctids;
-    config.apids = &apids;
-    config.ctids = &ctids;
-    config.file_name = (char *)"Test";
-    config.records = NULL;
-    config.log = NULL;
-    config.cache = NULL;
-    config.file_size = 0;
-    config.sync = DLT_LOGSTORAGE_SYNC_ON_DEMAND;
-    config.num_files = 7;
-    config.file_size = 50;
-    g_logstorage_cache_max = 16;
-    unsigned int size = 10;
-    unsigned char data1[10] = "Dlt_data0";
-    unsigned char data2[10] = "Dlt_data1";
-    unsigned char data3[10] = "Dlt_data2";
-
-    config.cache = calloc(1, 50 + sizeof(DltLogStorageCacheFooter));
-
-    if (config.cache != NULL) {
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_prepare_msg_cache(&config, &file_config, path, 1));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, data1, size, data2, size, data3, size));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_sync_capable_data_to_file(&config, 0));
-        free(config.cache);
-        config.cache = NULL;
-    }
-}
-
-TEST(t_dlt_logstorage_sync_capable_data_to_file, null)
-{
-    EXPECT_EQ(DLT_RETURN_WRONG_PARAMETER, dlt_logstorage_sync_capable_data_to_file(NULL, 0));
 }
 
 /* Begin Method: dlt_logstorage::t_dlt_logstorage_sync_msg_cache*/
@@ -1659,7 +1625,7 @@ TEST(t_dlt_logstorage_sync_msg_cache, normal)
 
     if (config.cache != NULL) {
         EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_prepare_msg_cache(&config, &file_config, path, 1));
-        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, data1, size, data2, size, data3, size));
+        EXPECT_EQ(DLT_RETURN_OK, dlt_logstorage_write_msg_cache(&config, &file_config, path, data1, size, data2, size, data3, size));
         EXPECT_EQ(DLT_RETURN_OK,
                   dlt_logstorage_sync_msg_cache(&config, &file_config, path, DLT_LOGSTORAGE_SYNC_ON_DEMAND));
         free(config.cache);
@@ -1674,13 +1640,14 @@ TEST(t_dlt_logstorage_sync_msg_cache, null)
 
 int connectServer(void)
 {
+#ifdef DLT_USE_UNIX_SOCKET_IPC
     int sockfd, portno;
     struct sockaddr_in serv_addr;
     struct hostent *server;
     portno = 8080;
     sockfd = socket(AF_INET, SOCK_STREAM, 0);
     server = gethostbyname("127.0.0.1");
-    bzero((char *)&serv_addr, sizeof(serv_addr));
+    memset((char *) &serv_addr, 0, sizeof(serv_addr));
     serv_addr.sin_family = AF_INET;
     memcpy((char *)&serv_addr.sin_addr.s_addr,
            (char *)server->h_addr,
@@ -1692,6 +1659,17 @@ int connectServer(void)
         close(sockfd);
         return -1;
     }
+#else
+    char filename[1024];
+    int sockfd;
+    snprintf(filename, 1024, "/tmp/dltpipes/dlt%d", getpid());
+    /* Try to delete existing pipe, ignore result of unlink */
+    unlink(filename);
+
+    mkfifo(filename, S_IRUSR | S_IWUSR | S_IWGRP | S_IRGRP);
+    chmod(filename, S_IRUSR | S_IWUSR | S_IWGRP | S_IRGRP);
+    sockfd = open(filename, O_RDWR | O_CLOEXEC);
+#endif
 
     return sockfd;
 }
@@ -1700,6 +1678,7 @@ int connectServer(void)
 
 int main(int argc, char **argv)
 {
+#ifdef DLT_USE_UNIX_SOCKET_IPC
     pid_t cpid;
     cpid = fork();
 
@@ -1722,7 +1701,7 @@ int main(int argc, char **argv)
             return -1;
         }
 
-        bzero((char *)&serv_addr, sizeof(serv_addr));
+        memset((char *) &serv_addr, 0, sizeof(serv_addr));
         portno = 8080;
 
         serv_addr.sin_family = AF_INET;
@@ -1765,12 +1744,14 @@ int main(int argc, char **argv)
         close(sockfd);
     }
     else {
-
+#endif
         ::testing::InitGoogleTest(&argc, argv);
         ::testing::FLAGS_gtest_break_on_failure = false;
 /*        ::testing::FLAGS_gtest_filter = "t_dlt_event_handler_register_connection*"; */
         return RUN_ALL_TESTS();
+#ifdef DLT_USE_UNIX_SOCKET_IPC
     }
+#endif
 
     return 0;
 }
